@@ -33,8 +33,8 @@ OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 """
 
-__version__ = '0.4.12'
-__author__ = 'Qing Yu <qingyu0815@foxmail.com>'
+__version__ = '0.4.13'
+__author__ = 'Qing Yu <yuq@sustech.edu.cn>'
 
 # module level doc-string
 __doc__ = """
@@ -86,7 +86,9 @@ from .plotmap import (
     plot_map,
     plotscale,
     set_mapboxtoken,
-    set_imgsavepath
+    set_imgsavepath,
+    read_imgsavepath,
+    read_mapboxtoken
 )
 from .coordinates import (
     gcj02tobd09,
