@@ -80,12 +80,12 @@ def area_to_grid(location, accuracy=500, method='rect', params='auto'):
         shape = location
         bounds = shape.unary_union.bounds
     else:
-        raise Exception(
+        raise Exception(  # pragma: no cover
             'Location should be either bounds(List) or shape(GeoDataFrame)')
     lon1, lat1, lon2, lat2 = bounds
     if (lon1 > lon2) | (lat1 > lat2) | (abs(lat1) > 90) | (abs(lon1) > 180) | (
             abs(lat2) > 90) | (abs(lon2) > 180):
-        raise Exception(
+        raise Exception(  # pragma: no cover
             'Bounds error. The input bounds should be in the order of \
                 [lon1,lat1,lon2,lat2]. (lon1,lat1) is the lower left \
                     corner and (lon2,lat2) is the upper right corner.'
@@ -191,7 +191,7 @@ def area_to_params(location, accuracy=500, method='rect'):
     lon1, lat1, lon2, lat2 = bounds
     if (lon1 > lon2) | (lat1 > lat2) | (abs(lat1) > 90) | (abs(lon1) > 180) | (
             abs(lat2) > 90) | (abs(lon2) > 180):
-        raise Exception(
+        raise Exception(   # pragma: no cover
             'Bounds error. The input bounds should be in the order \
                 of [lon1,lat1,lon2,lat2]. (lon1,lat1) is the lower left \
                     corner and (lon2,lat2) is the upper right corner.'
@@ -331,7 +331,7 @@ def grid_to_centre(gridid, params):
             if np.allclose((x2[0]-x1[0]), 0):
                 return x1, (x1-x3)*(y3-y4)/(x3-x4)+y3
             elif np.allclose((x3[0]-x4[0]), 0):
-                return x3, (x3-x1)*(y1-y2)/(x1-x2)+y1
+                return x3, (x3-x1)*(y1-y2)/(x1-x2)+y1   # pragma: no cover
             x = (x1*(y2-y1)/(x2-x1)-x3/(x4-x3)*(y4-y3)+y3-y1) / \
                 ((y2-y1)/(x2-x1)-(y4-y3)/(x4-x3))
             y = (x-x1)*(y2-y1)/(x2-x1)+y1
@@ -473,8 +473,8 @@ def grid_params_optimize(data,
                          pop=15,
                          max_iter=50,
                          w=0.1,
-                        c1=0.5,
-                        c2=0.5):
+                         c1=0.5,
+                         c2=0.5):
     '''
     Optimize the grid params
 
@@ -514,8 +514,8 @@ def grid_params_optimize(data,
     [uid, lon, lat] = col
     try:
         from sko.PSO import PSO
-    except ImportError:
-        raise ImportError(
+    except ImportError:  # pragma: no cover
+        raise ImportError(  # pragma: no cover
             "Please install scikit-opt, run following code "
             "in cmd: pip install scikit-opt")
 
@@ -626,18 +626,19 @@ def grid_params_optimize(data,
 
         f = f_gridscount
     else:
-        raise Exception('Method should be one of: centerdist,gini,gridscount')
+        raise Exception(
+            'Method should be one of: centerdist,gini,gridscount')  # pragma: no cover
 
     pso = PSO(func=f,
-            n_dim=3,
-            pop=pop, 
-            max_iter=max_iter,
-            lb=[0, 0, 0],
-            ub=[params['deltalon'] * times, params['deltalat']
-                * times, 90 * theta_lambda],
-            w=w, 
-            c1=c1, 
-            c2=c2)
+              n_dim=3,
+              pop=pop,
+              max_iter=max_iter,
+              lb=[0, 0, 0],
+              ub=[params['deltalon'] * times, params['deltalat']
+                  * times, 90 * theta_lambda],
+              w=w,
+              c1=c1,
+              c2=c2)
     result = pso.run()
 
     x = result[0]
@@ -749,7 +750,7 @@ def grid_to_centre_rect(loncol, latcol, params, from_origin=False):
     R = np.array([[costheta * deltaLon, -sintheta * deltaLat],
                   [sintheta * deltaLon, costheta * deltaLat]])
     if from_origin:
-        hblonhblat = np.dot(np.array([loncol.values, latcol.values]).T,
+        hblonhblat = np.dot(np.array([loncol.values, latcol.values]).T,   # pragma: no cover
                             R) + np.array([lonStart, latStart]) - (
                                 R[0, :] / 2 + R[1, :] / 2)
     else:
@@ -1069,7 +1070,7 @@ def gettripoints(loncol_1, loncol_2, loncol_3, params):
         if np.allclose((x2[0]-x1[0]), 0):
             return x1, (x1-x3)*(y3-y4)/(x3-x4)+y3
         elif np.allclose((x3[0]-x4[0]), 0):
-            return x3, (x3-x1)*(y1-y2)/(x1-x2)+y1
+            return x3, (x3-x1)*(y1-y2)/(x1-x2)+y1   # pragma: no cover
         x = (x1*(y2-y1)/(x2-x1)-x3/(x4-x3)*(y4-y3)+y3-y1) / \
             ((y2-y1)/(x2-x1)-(y4-y3)/(x4-x3))
         y = (x-x1)*(y2-y1)/(x2-x1)+y1
@@ -1189,8 +1190,8 @@ def convertparams(params):
         elif len(params) == 5:
             lonStart, latStart, deltaLon, deltaLat, theta = params
             method = 'rect'
-        elif len(params) == 6:
-            lonStart, latStart, deltaLon, deltaLat, theta, method = params
+        elif len(params) == 6:  # pragma: no cover
+            lonStart, latStart, deltaLon, deltaLat, theta, method = params  # pragma: no cover
         dicparams = dict()
         dicparams['slon'] = lonStart
         dicparams['slat'] = latStart
@@ -1201,11 +1202,12 @@ def convertparams(params):
     else:
         dicparams = params
         if 'theta' not in dicparams:
-            dicparams['theta'] = 0
+            dicparams['theta'] = 0  # pragma: no cover
         if 'method' not in dicparams:
-            dicparams['method'] = 'rect'
+            dicparams['method'] = 'rect'  # pragma: no cover
     if dicparams['method'] not in ['rect', 'tri', 'hexa']:
-        raise ValueError('Method should be `rect`,`tri` or `hexa`')
+        raise ValueError(
+            'Method should be `rect`,`tri` or `hexa`')  # pragma: no cover
     return dicparams
 
 
